import { Button } from "@/components/ui/button";

interface PaginationProps {
  currentPage: number;
  totalPages: number;
  onPageChange: (page: number) => void;
}

const Pagination = ({ currentPage, totalPages, onPageChange }: PaginationProps) => {
  if (totalPages <= 1) return null;
  
  // Generate pages array: always show first, last, current, and surrounding pages
  const getPageNumbers = () => {
    const pages = [];
    
    // Always show first page
    pages.push(1);
    
    // Add ellipsis if needed
    if (currentPage > 3) {
      pages.push("ellipsis-start");
    }
    
    // Add pages surrounding current page
    for (let i = Math.max(2, currentPage - 1); i <= Math.min(totalPages - 1, currentPage + 1); i++) {
      if (i === 1 || i === totalPages) continue; // Skip first and last pages (already added)
      pages.push(i);
    }
    
    // Add ellipsis if needed
    if (currentPage < totalPages - 2) {
      pages.push("ellipsis-end");
    }
    
    // Always show last page if more than 1 page
    if (totalPages > 1) {
      pages.push(totalPages);
    }
    
    return pages;
  };
  
  const pages = getPageNumbers();
  
  return (
    <div className="mt-8 flex justify-center">
      <div className="inline-flex rounded-md shadow-sm">
        <Button
          variant="outline"
          onClick={() => onPageChange(Math.max(1, currentPage - 1))}
          disabled={currentPage === 1}
          className="px-4 py-2 text-sm rounded-l-md"
        >
          <i className="fas fa-chevron-left"></i>
        </Button>
        
        {pages.map((page, index) => {
          if (page === "ellipsis-start" || page === "ellipsis-end") {
            return (
              <Button
                key={`ellipsis-${index}`}
                variant="outline"
                disabled
                className="px-4 py-2 text-sm"
              >
                ...
              </Button>
            );
          }
          
          const pageNumber = page as number;
          
          return (
            <Button
              key={pageNumber}
              variant={currentPage === pageNumber ? "default" : "outline"}
              onClick={() => onPageChange(pageNumber)}
              className={`px-4 py-2 text-sm ${
                currentPage === pageNumber 
                  ? "text-white bg-primary border-primary" 
                  : "text-gray-700 hover:bg-gray-50"
              }`}
            >
              {pageNumber}
            </Button>
          );
        })}
        
        <Button
          variant="outline"
          onClick={() => onPageChange(Math.min(totalPages, currentPage + 1))}
          disabled={currentPage === totalPages}
          className="px-4 py-2 text-sm rounded-r-md"
        >
          <i className="fas fa-chevron-right"></i>
        </Button>
      </div>
    </div>
  );
};

export default Pagination;
